@@ -257,7 +257,7 @@ void ProfilDialog::accept()
     profile->SetName(ui->lineEdit_nameprofile->text());
 
     profile->SetRingingAlertVolume(QVariant(ui->slider_ringing_volume->value()));
-    profile->SetSmsAlertVolume(QVariant(ui->slider_im_volume->value()));
+    profile->SetSmsAlertVolume(QVariant(ui->slider_sms_volume->value()));
     profile->SetImAlertVolume(QVariant(ui->slider_im_volume->value()));
     profile->SetEmailAlertVolume(QVariant(ui->slider_email_volume->value()));
 
